=============
User Guide
=============

Dataset
========
.. toctree::
   :maxdepth: 4

   datasets.rst

Common Usage Examples
======================
.. toctree::
   :maxdepth: 4

   basic_usage

Random Sampling from PKBD
===========================
.. toctree::
   :maxdepth: 4

   gen_plot_rpkb